Struct Seq1
#[repr(transparent)]pub struct Seq1(pub u32);Expand description
SEQ_1 register.
Tuple Fields
0: u32Implementations
impl Seq1
impl Seq1
pub const fn seq0(&self) -> u8
pub const fn seq0(&self) -> u8
SEQ0[3:0]: channel number code for first conversion of the sequence 0000: VINM[0] to ADC single negative input 0001: VINM[1] to ADC single negative input 0010: VINM[2] to ADC single negative input 0011: VINM[3] to ADC single negative input 0100: VINP[0] to ADC single positive input 0101: VINP[1] to ADC single positive input 0110: VINP[2] to ADC single positive input 0111: VINP[3] to ADC single positive input 1000: VINP[0]-VINM[0] to ADC differential input 1001: VINP[1]-VINM[1] to ADC differential input 1010: VINP[2]-VINM[2] to ADC differential input 1011: VINP[3]-VINM[3] to ADC differential input 1100: VBAT - Battery level detector 1101: Temperature sensor 111x: reserved.
pub fn set_seq0(&mut self, val: u8)
pub fn set_seq0(&mut self, val: u8)
SEQ0[3:0]: channel number code for first conversion of the sequence 0000: VINM[0] to ADC single negative input 0001: VINM[1] to ADC single negative input 0010: VINM[2] to ADC single negative input 0011: VINM[3] to ADC single negative input 0100: VINP[0] to ADC single positive input 0101: VINP[1] to ADC single positive input 0110: VINP[2] to ADC single positive input 0111: VINP[3] to ADC single positive input 1000: VINP[0]-VINM[0] to ADC differential input 1001: VINP[1]-VINM[1] to ADC differential input 1010: VINP[2]-VINM[2] to ADC differential input 1011: VINP[3]-VINM[3] to ADC differential input 1100: VBAT - Battery level detector 1101: Temperature sensor 111x: reserved.
pub const fn seq1(&self) -> u8
pub const fn seq1(&self) -> u8
SEQ1[3:0]: channel number code for second conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq1(&mut self, val: u8)
pub fn set_seq1(&mut self, val: u8)
SEQ1[3:0]: channel number code for second conversion of the sequence. See SEQ0 for code detail.
pub const fn seq2(&self) -> u8
pub const fn seq2(&self) -> u8
SEQ2[3:0]: channel number code for 3rd conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq2(&mut self, val: u8)
pub fn set_seq2(&mut self, val: u8)
SEQ2[3:0]: channel number code for 3rd conversion of the sequence. See SEQ0 for code detail.
pub const fn seq3(&self) -> u8
pub const fn seq3(&self) -> u8
SEQ3[3:0]: channel number code for 4th conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq3(&mut self, val: u8)
pub fn set_seq3(&mut self, val: u8)
SEQ3[3:0]: channel number code for 4th conversion of the sequence. See SEQ0 for code detail.
pub const fn seq4(&self) -> u8
pub const fn seq4(&self) -> u8
SEQ4[3:0]: channel number code for 5th conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq4(&mut self, val: u8)
pub fn set_seq4(&mut self, val: u8)
SEQ4[3:0]: channel number code for 5th conversion of the sequence. See SEQ0 for code detail.
pub const fn seq5(&self) -> u8
pub const fn seq5(&self) -> u8
SEQ5[3:0]: channel number code for 6th conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq5(&mut self, val: u8)
pub fn set_seq5(&mut self, val: u8)
SEQ5[3:0]: channel number code for 6th conversion of the sequence. See SEQ0 for code detail.
pub const fn seq6(&self) -> u8
pub const fn seq6(&self) -> u8
SEQ6[3:0]: channel number code for 7th conversion of the sequence. See SEQ0 for code detail.
pub fn set_seq6(&mut self, val: u8)
pub fn set_seq6(&mut self, val: u8)
SEQ6[3:0]: channel number code for 7th conversion of the sequence. See SEQ0 for code detail.