Struct TimerConf
#[repr(transparent)]pub struct TimerConf(pub u32);Expand description
Time to add after an LDO Enable or ADC Enable to let the HW to be stable before using it.
Tuple Fields
0: u32Implementations
impl TimerConf
impl TimerConf
pub const fn adc_ldo_delay(&self) -> u8
pub const fn adc_ldo_delay(&self) -> u8
define the duration of a waiting time to be inserted between the ADC_LDO enable and the ADC ON to let time to the LDO to stabilize before starting a conversion.
pub fn set_adc_ldo_delay(&mut self, val: u8)
pub fn set_adc_ldo_delay(&mut self, val: u8)
define the duration of a waiting time to be inserted between the ADC_LDO enable and the ADC ON to let time to the LDO to stabilize before starting a conversion.
pub const fn vbias_prech_delay(&self) -> u8
pub const fn vbias_prech_delay(&self) -> u8
define the duration of a waiting time starting at rising edge of PGA_EN signal and corresponding to the VBIAS precharge duration.
pub fn set_vbias_prech_delay(&mut self, val: u8)
pub fn set_vbias_prech_delay(&mut self, val: u8)
define the duration of a waiting time starting at rising edge of PGA_EN signal and corresponding to the VBIAS precharge duration.
pub const fn prech_delay_sel(&self) -> bool
pub const fn prech_delay_sel(&self) -> bool
Select the time step PD_STEP for the VBIAS_PRECH_DELAY timer.
pub fn set_prech_delay_sel(&mut self, val: bool)
pub fn set_prech_delay_sel(&mut self, val: bool)
Select the time step PD_STEP for the VBIAS_PRECH_DELAY timer.